"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    load_balancer_name: str,
    policy_name: str,
    policy_type_name: str,
    policy_attributes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a policy with the specified attributes for the specified load balancer. Policies are settings that are saved for your load balancer and that can be applied to the listener or the application server, depending on the policy type.

    Args:
        load_balancer_name(str): The name of the load balancer.
        policy_name(str): The name of the load balancer policy to be created. This name must be unique within the set of policies for this load balancer.
        policy_type_name(str): The name of the base policy type. To get the list of policy types, use DescribeLoadBalancerPolicyTypes.
        policy_attributes(List, optional): The policy attributes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.policy.init.create(
                ctx, load_balancer_name=value, policy_name=value, policy_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.policy.init.create load_balancer_name=value, policy_name=value, policy_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="create_load_balancer_policy",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "PolicyName": policy_name,
            "PolicyTypeName": policy_type_name,
            "PolicyAttributes": policy_attributes,
        },
    )


async def delete(hub, ctx, load_balancer_name: str, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified policy from the specified load balancer. This policy must not be enabled for any listeners.

    Args:
        load_balancer_name(str): The name of the load balancer.
        policy_name(str): The name of the policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.policy.init.delete(
                ctx, load_balancer_name=value, policy_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.policy.init.delete load_balancer_name=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="delete_load_balancer_policy",
        op_kwargs={"LoadBalancerName": load_balancer_name, "PolicyName": policy_name},
    )


async def describe_all(
    hub, ctx, load_balancer_name: str = None, policy_names: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified policies. If you specify a load balancer name, the action returns the descriptions of all policies created for the load balancer. If you specify a policy name associated with your load balancer, the action returns the description of that policy. If you don't specify a load balancer name, the action returns descriptions of the specified sample policies, or descriptions of all sample policies. The names of the sample policies have the ELBSample- prefix.

    Args:
        load_balancer_name(str, optional): The name of the load balancer. Defaults to None.
        policy_names(List, optional): The names of the policies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.policy.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.policy.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="describe_load_balancer_policies",
        op_kwargs={"LoadBalancerName": load_balancer_name, "PolicyNames": policy_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def start(hub, ctx, analyzer_arn: str, resource_arn: str) -> None:
    r"""
    **Autogenerated function**

    Immediately starts a scan of the policies applied to the specified resource.

    Args:
        analyzer_arn(str): The ARN of the analyzer to use to scan the policies applied to the specified resource.
        resource_arn(str): The ARN of the resource to scan.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.resource.scan.start(
                ctx, analyzer_arn=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.resource.scan.start analyzer_arn=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="start_resource_scan",
        op_kwargs={"analyzerArn": analyzer_arn, "resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    directory_id: str,
    type_: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the status of LDAP security for the specified directory.

    Args:
        directory_id(str): The identifier of the directory.
        type_(str, optional): The type of LDAP security to enable. Currently only the value Client is supported. Defaults to None.
        next_token(str, optional): The type of next token used for pagination. Defaults to None.
        limit(int, optional): Specifies the number of items that should be displayed on one page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.ldap.setting.describe_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.ldap.setting.describe_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_ldaps_settings",
        op_kwargs={
            "DirectoryId": directory_id,
            "Type": type_,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the metric policy that is associated with the specified container. If there is no metric policy associated with the container, MediaStore doesn't send metrics to CloudWatch.

    Args:
        container_name(str): The name of the container that is associated with the metric policy that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.metric_policy.delete(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.metric_policy.delete container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="delete_metric_policy",
        op_kwargs={"ContainerName": container_name},
    )


async def get(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the metric policy for the specified container.

    Args:
        container_name(str): The name of the container that is associated with the metric policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.metric_policy.get(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.metric_policy.get container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="get_metric_policy",
        op_kwargs={"ContainerName": container_name},
    )


async def put(hub, ctx, container_name: str, metric_policy: Dict) -> Dict:
    r"""
    **Autogenerated function**

    The metric policy that you want to add to the container. A metric policy allows AWS Elemental MediaStore to send metrics to Amazon CloudWatch. It takes up to 20 minutes for the new policy to take effect.

    Args:
        container_name(str): The name of the container that you want to add the metric policy to.
        metric_policy(Dict): The metric policy that you want to associate with the container. In the policy, you must indicate whether you want MediaStore to send container-level metrics. You can also include up to five rules to define groups of objects that you want MediaStore to send object-level metrics for. If you include rules in the policy, construct each rule with both of the following:   An object group that defines which objects to include in the group. The definition can be a path or a file name, but it can't have more than 900 characters. Valid characters are: a-z, A-Z, 0-9, _ (underscore), = (equal), : (colon), . (period), - (hyphen), ~ (tilde), / (forward slash), and * (asterisk). Wildcards (*) are acceptable.   An object group name that allows you to refer to the object group. The name can't have more than 30 characters. Valid characters are: a-z, A-Z, 0-9, and _ (underscore).  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.metric_policy.put(
                ctx, container_name=value, metric_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.metric_policy.put container_name=value, metric_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="put_metric_policy",
        op_kwargs={"ContainerName": container_name, "MetricPolicy": metric_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    infrastructure_configuration_arn: str,
    client_token: str,
    image_recipe_arn: str = None,
    container_recipe_arn: str = None,
    distribution_configuration_arn: str = None,
    image_tests_configuration: Dict = None,
    enhanced_image_metadata_enabled: bool = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new image. This request will create a new image along with all of the configured output resources defined in the distribution configuration. You must specify exactly one recipe for your image, using either a ContainerRecipeArn or an ImageRecipeArn.

    Args:
        image_recipe_arn(str, optional):  The Amazon Resource Name (ARN) of the image recipe that defines how images are configured, tested, and assessed. Defaults to None.
        container_recipe_arn(str, optional): The Amazon Resource Name (ARN) of the container recipe that defines how images are configured and tested. Defaults to None.
        distribution_configuration_arn(str, optional):  The Amazon Resource Name (ARN) of the distribution configuration that defines and configures the outputs of your pipeline. Defaults to None.
        infrastructure_configuration_arn(str):  The Amazon Resource Name (ARN) of the infrastructure configuration that defines the environment in which your image will be built and tested.
        image_tests_configuration(Dict, optional):  The image tests configuration of the image. Defaults to None.
        enhanced_image_metadata_enabled(bool, optional):  Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default. Defaults to None.
        tags(Dict, optional):  The tags of the image. Defaults to None.
        client_token(str):  The idempotency token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.init.create(
                ctx, infrastructure_configuration_arn=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.init.create infrastructure_configuration_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="create_image",
        op_kwargs={
            "imageRecipeArn": image_recipe_arn,
            "containerRecipeArn": container_recipe_arn,
            "distributionConfigurationArn": distribution_configuration_arn,
            "infrastructureConfigurationArn": infrastructure_configuration_arn,
            "imageTestsConfiguration": image_tests_configuration,
            "enhancedImageMetadataEnabled": enhanced_image_metadata_enabled,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, image_build_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes an image.

    Args:
        image_build_version_arn(str): The Amazon Resource Name (ARN) of the image to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.init.delete(
                ctx, image_build_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.init.delete image_build_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="delete_image",
        op_kwargs={"imageBuildVersionArn": image_build_version_arn},
    )


async def get(hub, ctx, image_build_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets an image.

    Args:
        image_build_version_arn(str): The Amazon Resource Name (ARN) of the image that you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.init.get(ctx, image_build_version_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.init.get image_build_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_image",
        op_kwargs={"imageBuildVersionArn": image_build_version_arn},
    )


async def list_all(
    hub,
    ctx,
    owner: str = None,
    filters: List = None,
    by_name: bool = None,
    max_results: int = None,
    next_token: str = None,
    include_deprecated: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the list of images that you have access to.

    Args:
        owner(str, optional): The owner defines which images you want to list. By default, this request will only show images owned by your account. You can use this field to specify if you want to view images owned by yourself, by Amazon, or those images that have been shared with you by other customers. Defaults to None.
        filters(List, optional): The filters. Defaults to None.
        by_name(bool, optional): Requests a list of images with a specific recipe name. Defaults to None.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.
        include_deprecated(bool, optional): Includes deprecated images in the response list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_images",
        op_kwargs={
            "owner": owner,
            "filters": filters,
            "byName": by_name,
            "maxResults": max_results,
            "nextToken": next_token,
            "includeDeprecated": include_deprecated,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    configuration_aggregator_name: str,
    filters: Dict = None,
    group_by_key: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator.  The results can return an empty result page, but if you have a nextToken, the results are displayed on the next page.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        filters(Dict, optional): Filters the results based on the ConfigRuleComplianceSummaryFilters object. Defaults to None.
        group_by_key(str, optional): Groups the result based on ACCOUNT_ID or AWS_REGION. Defaults to None.
        limit(int, optional): The maximum number of evaluation results returned on each page. The default is 1000. You cannot specify a number greater than 1000. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.config_rule_compliance_summary.get(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.config_rule_compliance_summary.get configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_aggregate_config_rule_compliance_summary",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "Filters": filters,
            "GroupByKey": group_by_key,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "available_management_cidr_range"


async def list_all(
    hub,
    ctx,
    management_cidr_range_constraint: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of IP address ranges, specified as IPv4 CIDR blocks, that you can use for the network management interface when you enable Bring Your Own License (BYOL).  This operation can be run only by AWS accounts that are enabled for BYOL. If your account isn't enabled for BYOL, you'll receive an AccessDeniedException error. The management network interface is connected to a secure Amazon WorkSpaces management network. It is used for interactive streaming of the WorkSpace desktop to Amazon WorkSpaces clients, and to allow Amazon WorkSpaces to manage the WorkSpace.

    Args:
        management_cidr_range_constraint(str): The IP address range to search. Specify an IP address range that is compatible with your network and in CIDR notation (that is, specify the range as an IPv4 CIDR block).
        max_results(int, optional): The maximum number of items to return. Defaults to None.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.available_management_cidr_range_.list_all(
                ctx, management_cidr_range_constraint=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.available_management_cidr_range.list_all management_cidr_range_constraint=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="list_available_management_cidr_ranges",
        op_kwargs={
            "ManagementCidrRangeConstraint": management_cidr_range_constraint,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, workbook_id: str, table_id: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The DescribeTableDataImportJob API allows you to retrieve the status and details of a table data import job.

    Args:
        workbook_id(str): The ID of the workbook into which data was imported.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table into which data was imported.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        job_id(str): The ID of the job that was returned by the StartTableDataImportJob request.  If a job with the specified id could not be found, this API throws ResourceNotFoundException. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.table.data_import_job.describe(
                ctx, workbook_id=value, table_id=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.table.data_import_job.describe workbook_id=value, table_id=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="describe_table_data_import_job",
        op_kwargs={"workbookId": workbook_id, "tableId": table_id, "jobId": job_id},
    )


async def start(
    hub,
    ctx,
    workbook_id: str,
    data_source: Dict,
    data_format: str,
    destination_table_id: str,
    import_options: Dict,
    client_request_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

     The StartTableDataImportJob API allows you to start an import job on a table. This API will only return the id of the job that was started. To find out the status of the import request, you need to call the DescribeTableDataImportJob API.

    Args:
        workbook_id(str): The ID of the workbook where the rows are being imported.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        data_source(Dict):  The source of the data that is being imported. The size of source must be no larger than 100 MB. Source must have no more than 100,000 cells and no more than 1,000 rows. .
        data_format(str):  The format of the data that is being imported. Currently the only option supported is "DELIMITED_TEXT". .
        destination_table_id(str): The ID of the table where the rows are being imported.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        import_options(Dict):  The options for customizing this import request. .
        client_request_token(str):  The request token for performing the update action. Request tokens help to identify duplicate requests. If a call times out or fails due to a transient error like a failed network connection, you can retry the call with the same request token. The service ensures that if the first call using that request token is successfully performed, the second call will not perform the action again.   Note that request tokens are valid only for a few minutes. You cannot use request tokens to dedupe requests spanning hours or days. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.table.data_import_job.start(
                ctx,
                workbook_id=value,
                data_source=value,
                data_format=value,
                destination_table_id=value,
                import_options=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.table.data_import_job.start workbook_id=value, data_source=value, data_format=value, destination_table_id=value, import_options=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="start_table_data_import_job",
        op_kwargs={
            "workbookId": workbook_id,
            "dataSource": data_source,
            "dataFormat": data_format,
            "destinationTableId": destination_table_id,
            "importOptions": import_options,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    thing_group_name: str,
    query_string: str,
    thing_group_properties: Dict = None,
    index_name: str = None,
    query_version: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a dynamic thing group.

    Args:
        thing_group_name(str): The dynamic thing group name to create.
        thing_group_properties(Dict, optional): The dynamic thing group properties. Defaults to None.
        index_name(str, optional): The dynamic thing group index name.  Currently one index is supported: "AWS_Things". . Defaults to None.
        query_string(str): The dynamic thing group search query string. See Query Syntax for information about query string syntax.
        query_version(str, optional): The dynamic thing group query version.  Currently one query version is supported: "2017-09-30". If not specified, the query version defaults to this value. . Defaults to None.
        tags(List, optional): Metadata which can be used to manage the dynamic thing group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dynamic_thing_group.create(
                ctx, thing_group_name=value, query_string=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dynamic_thing_group.create thing_group_name=value, query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_dynamic_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "thingGroupProperties": thing_group_properties,
            "indexName": index_name,
            "queryString": query_string,
            "queryVersion": query_version,
            "tags": tags,
        },
    )


async def delete(hub, ctx, thing_group_name: str, expected_version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a dynamic thing group.

    Args:
        thing_group_name(str): The name of the dynamic thing group to delete.
        expected_version(int, optional): The expected version of the dynamic thing group to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dynamic_thing_group.delete(ctx, thing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dynamic_thing_group.delete thing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_dynamic_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "expectedVersion": expected_version,
        },
    )


async def update(
    hub,
    ctx,
    thing_group_name: str,
    thing_group_properties: Dict,
    expected_version: int = None,
    index_name: str = None,
    query_string: str = None,
    query_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a dynamic thing group.

    Args:
        thing_group_name(str): The name of the dynamic thing group to update.
        thing_group_properties(Dict): The dynamic thing group properties to update.
        expected_version(int, optional): The expected version of the dynamic thing group to update. Defaults to None.
        index_name(str, optional): The dynamic thing group index to update.  Currently one index is supported: 'AWS_Things'. . Defaults to None.
        query_string(str, optional): The dynamic thing group search query string to update. Defaults to None.
        query_version(str, optional): The dynamic thing group query version to update.  Currently one query version is supported: "2017-09-30". If not specified, the query version defaults to this value. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dynamic_thing_group.update(
                ctx, thing_group_name=value, thing_group_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dynamic_thing_group.update thing_group_name=value, thing_group_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_dynamic_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "thingGroupProperties": thing_group_properties,
            "expectedVersion": expected_version,
            "indexName": index_name,
            "queryString": query_string,
            "queryVersion": query_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, dhcp_options_id: str, vpc_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Associates a set of DHCP options (that you've previously created) with the specified VPC, or associates no DHCP options with the VPC. After you associate the options with the VPC, any existing instances and all new instances that you launch in that VPC use the options. You don't need to restart or relaunch the instances. They automatically pick up the changes within a few hours, depending on how frequently the instance renews its DHCP lease. You can explicitly renew the lease using the operating system on the instance. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.

    Args:
        dhcp_options_id(str): The ID of the DHCP options set, or default to associate no DHCP options with the VPC.
        vpc_id(str): The ID of the VPC.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.dhcp_option.associate(
                ctx, dhcp_options_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.dhcp_option.associate dhcp_options_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_dhcp_options",
        op_kwargs={
            "DhcpOptionsId": dhcp_options_id,
            "VpcId": vpc_id,
            "DryRun": dry_run,
        },
    )


async def create_multiple(
    hub,
    ctx,
    dhcp_configurations: List,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a set of DHCP options for your VPC. After creating the set, you must associate it with the VPC, causing all existing and new instances that you launch in the VPC to use this set of DHCP options. The following are the individual DHCP options you can specify. For more information about the options, see RFC 2132.    domain-name-servers - The IP addresses of up to four domain name servers, or AmazonProvidedDNS. The default DHCP option set specifies AmazonProvidedDNS. If specifying more than one domain name server, specify the IP addresses in a single parameter, separated by commas. To have your instance receive a custom DNS hostname as specified in domain-name, you must set domain-name-servers to a custom DNS server.    domain-name - If you're using AmazonProvidedDNS in us-east-1, specify ec2.internal. If you're using AmazonProvidedDNS in another Region, specify region.compute.internal (for example, ap-northeast-1.compute.internal). Otherwise, specify a domain name (for example, ExampleCompany.com). This value is used to complete unqualified DNS hostnames. Important: Some Linux operating systems accept multiple domain names separated by spaces. However, Windows and other Linux operating systems treat the value as a single domain, which results in unexpected behavior. If your DHCP options set is associated with a VPC that has instances with multiple operating systems, specify only one domain name.    ntp-servers - The IP addresses of up to four Network Time Protocol (NTP) servers.    netbios-name-servers - The IP addresses of up to four NetBIOS name servers.    netbios-node-type - The NetBIOS node type (1, 2, 4, or 8). We recommend that you specify 2 (broadcast and multicast are not currently supported). For more information about these node types, see RFC 2132.   Your VPC automatically starts out with a set of DHCP options that includes only a DNS server that we provide (AmazonProvidedDNS). If you create a set of options, and if your VPC has an internet gateway, make sure to set the domain-name-servers option either to AmazonProvidedDNS or to a domain name server of your choice. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.

    Args:
        dhcp_configurations(List): A DHCP configuration option.
        tag_specifications(List, optional): The tags to assign to the DHCP option. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.dhcp_option.create_multiple(ctx, dhcp_configurations=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.dhcp_option.create_multiple dhcp_configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_dhcp_options",
        op_kwargs={
            "DhcpConfigurations": dhcp_configurations,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete_multiple(hub, ctx, dhcp_options_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified set of DHCP options. You must disassociate the set of DHCP options before you can delete it. You can disassociate the set of DHCP options by associating either a new set of options or the default set of options with the VPC.

    Args:
        dhcp_options_id(str): The ID of the DHCP options set.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.dhcp_option.delete_multiple(ctx, dhcp_options_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.dhcp_option.delete_multiple dhcp_options_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_dhcp_options",
        op_kwargs={"DhcpOptionsId": dhcp_options_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    dhcp_options_ids: List = None,
    filters: List = None,
    dry_run: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your DHCP options sets. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.

    Args:
        dhcp_options_ids(List, optional): The IDs of one or more DHCP options sets. Default: Describes all your DHCP options sets. Defaults to None.
        filters(List, optional): One or more filters.    dhcp-options-id - The ID of a DHCP options set.    key - The key for one of the options (for example, domain-name).    value - The value for one of the options.    owner-id - The ID of the Amazon Web Services account that owns the DHCP options set.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.dhcp_option.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.dhcp_option.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_dhcp_options",
        op_kwargs={
            "DhcpOptionsIds": dhcp_options_ids,
            "Filters": filters,
            "DryRun": dry_run,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    reserved_node_offering_id: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the available reserved node offerings by Amazon Redshift with their descriptions including the node type, the fixed and recurring costs of reserving the node and duration the node will be reserved for you. These descriptions help you determine which reserve node offering you want to purchase. You then use the unique offering ID in you call to PurchaseReservedNodeOffering to reserve one or more nodes for your Amazon Redshift cluster.   For more information about reserved node offerings, go to Purchasing Reserved Nodes in the Amazon Redshift Cluster Management Guide.

    Args:
        reserved_node_offering_id(str, optional): The unique identifier for the offering. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeReservedNodeOfferings request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.reserved_node.offering.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.reserved_node.offering.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_reserved_node_offerings",
        op_kwargs={
            "ReservedNodeOfferingId": reserved_node_offering_id,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def purchase(
    hub, ctx, reserved_node_offering_id: str, node_count: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to purchase reserved nodes. Amazon Redshift offers a predefined set of reserved node offerings. You can purchase one or more of the offerings. You can call the DescribeReservedNodeOfferings API to obtain the available reserved node offerings. You can call this API by providing a specific reserved node offering and the number of nodes you want to reserve.   For more information about reserved node offerings, go to Purchasing Reserved Nodes in the Amazon Redshift Cluster Management Guide.

    Args:
        reserved_node_offering_id(str): The unique identifier of the reserved node offering you want to purchase.
        node_count(int, optional): The number of reserved nodes that you want to purchase. Default: 1 . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.reserved_node.offering.purchase(
                ctx, reserved_node_offering_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.reserved_node.offering.purchase reserved_node_offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="purchase_reserved_node_offering",
        op_kwargs={
            "ReservedNodeOfferingId": reserved_node_offering_id,
            "NodeCount": node_count,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def send(
    hub,
    ctx,
    destination: Dict,
    content: Dict,
    from_email_address: str = None,
    reply_to_addresses: List = None,
    feedback_forwarding_email_address: str = None,
    email_tags: List = None,
    configuration_set_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends an email message. You can use the Amazon Pinpoint Email API to send two types of messages:    Simple – A standard email message. When you create this type of message, you specify the sender, the recipient, and the message body, and Amazon Pinpoint assembles the message for you.    Raw – A raw, MIME-formatted email message. When you send this type of email, you have to specify all of the message headers, as well as the message body. You can use this message type to send messages that contain attachments. The message that you specify has to be a valid MIME message.

    Args:
        from_email_address(str, optional): The email address that you want to use as the "From" address for the email. The address that you specify has to be verified. . Defaults to None.
        destination(Dict): An object that contains the recipients of the email message.
        reply_to_addresses(List, optional): The "Reply-to" email addresses for the message. When the recipient replies to the message, each Reply-to address receives the reply. Defaults to None.
        feedback_forwarding_email_address(str, optional): The address that Amazon Pinpoint should send bounce and complaint notifications to. Defaults to None.
        content(Dict): An object that contains the body of the message. You can send either a Simple message or a Raw message.
        email_tags(List, optional): A list of tags, in the form of name/value pairs, to apply to an email that you send using the SendEmail operation. Tags correspond to characteristics of the email that you define, so that you can publish email sending events. . Defaults to None.
        configuration_set_name(str, optional): The name of the configuration set that you want to use when sending the email. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.init.send(
                ctx, destination=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.init.send destination=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="send_email",
        op_kwargs={
            "FromEmailAddress": from_email_address,
            "Destination": destination,
            "ReplyToAddresses": reply_to_addresses,
            "FeedbackForwardingEmailAddress": feedback_forwarding_email_address,
            "Content": content,
            "EmailTags": email_tags,
            "ConfigurationSetName": configuration_set_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    ttl: int,
    api_caching_behavior: str,
    type_: str,
    transit_encryption_enabled: bool = None,
    at_rest_encryption_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a cache for the GraphQL API.

    Args:
        api_id(str): The GraphQL API Id.
        ttl(int): TTL in seconds for cache entries. Valid values are between 1 and 3600 seconds.
        transit_encryption_enabled(bool, optional): Transit encryption flag when connecting to cache. This setting cannot be updated after creation. Defaults to None.
        at_rest_encryption_enabled(bool, optional): At rest encryption flag for cache. This setting cannot be updated after creation. Defaults to None.
        api_caching_behavior(str): Caching behavior.    FULL_REQUEST_CACHING: All requests are fully cached.    PER_RESOLVER_CACHING: Individual resolvers that you specify are cached.  .
        type_(str): The cache instance type. Valid values are     SMALL     MEDIUM     LARGE     XLARGE     LARGE_2X     LARGE_4X     LARGE_8X (not available in all regions)    LARGE_12X    Historically, instance types were identified by an EC2-style value. As of July 2020, this is deprecated, and the generic identifiers above should be used. The following legacy instance types are available, but their use is discouraged:    T2_SMALL: A t2.small instance type.    T2_MEDIUM: A t2.medium instance type.    R4_LARGE: A r4.large instance type.    R4_XLARGE: A r4.xlarge instance type.    R4_2XLARGE: A r4.2xlarge instance type.    R4_4XLARGE: A r4.4xlarge instance type.    R4_8XLARGE: A r4.8xlarge instance type.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.cache.create(
                ctx, api_id=value, ttl=value, api_caching_behavior=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.cache.create api_id=value, ttl=value, api_caching_behavior=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="create_api_cache",
        op_kwargs={
            "apiId": api_id,
            "ttl": ttl,
            "transitEncryptionEnabled": transit_encryption_enabled,
            "atRestEncryptionEnabled": at_rest_encryption_enabled,
            "apiCachingBehavior": api_caching_behavior,
            "type": type_,
        },
    )


async def delete(hub, ctx, api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an ApiCache object.

    Args:
        api_id(str): The API ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.cache.delete(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.cache.delete api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="delete_api_cache",
        op_kwargs={"apiId": api_id},
    )


async def flush(hub, ctx, api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Flushes an ApiCache object.

    Args:
        api_id(str): The API ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.cache.flush(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.cache.flush api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="flush_api_cache",
        op_kwargs={"apiId": api_id},
    )


async def get(hub, ctx, api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an ApiCache object.

    Args:
        api_id(str): The API ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.cache.get(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.cache.get api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="get_api_cache",
        op_kwargs={"apiId": api_id},
    )


async def update(
    hub, ctx, api_id: str, ttl: int, api_caching_behavior: str, type_: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the cache for the GraphQL API.

    Args:
        api_id(str): The GraphQL API Id.
        ttl(int): TTL in seconds for cache entries. Valid values are between 1 and 3600 seconds.
        api_caching_behavior(str): Caching behavior.    FULL_REQUEST_CACHING: All requests are fully cached.    PER_RESOLVER_CACHING: Individual resolvers that you specify are cached.  .
        type_(str): The cache instance type. Valid values are     SMALL     MEDIUM     LARGE     XLARGE     LARGE_2X     LARGE_4X     LARGE_8X (not available in all regions)    LARGE_12X    Historically, instance types were identified by an EC2-style value. As of July 2020, this is deprecated, and the generic identifiers above should be used. The following legacy instance types are available, but their use is discouraged:    T2_SMALL: A t2.small instance type.    T2_MEDIUM: A t2.medium instance type.    R4_LARGE: A r4.large instance type.    R4_XLARGE: A r4.xlarge instance type.    R4_2XLARGE: A r4.2xlarge instance type.    R4_4XLARGE: A r4.4xlarge instance type.    R4_8XLARGE: A r4.8xlarge instance type.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.cache.update(
                ctx, api_id=value, ttl=value, api_caching_behavior=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.cache.update api_id=value, ttl=value, api_caching_behavior=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="update_api_cache",
        op_kwargs={
            "apiId": api_id,
            "ttl": ttl,
            "apiCachingBehavior": api_caching_behavior,
            "type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    bundle_name: str,
    bundle_description: str,
    image_id: str,
    compute_type: Dict,
    user_storage: Dict,
    root_storage: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the specified WorkSpace bundle. For more information about creating WorkSpace bundles, see  Create a Custom WorkSpaces Image and Bundle.

    Args:
        bundle_name(str): The name of the bundle.
        bundle_description(str): The description of the bundle.
        image_id(str): The identifier of the image that is used to create the bundle.
        compute_type(Dict): Describes the compute type of the bundle.
        user_storage(Dict): Describes the user volume for a WorkSpace bundle.
        root_storage(Dict, optional): Describes the root volume for a WorkSpace bundle. Defaults to None.
        tags(List, optional): The tags associated with the bundle.  To add tags at the same time when you're creating the bundle, you must create an IAM policy that grants your IAM user permissions to use workspaces:CreateTags.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.bundle.create(
                ctx,
                bundle_name=value,
                bundle_description=value,
                image_id=value,
                compute_type=value,
                user_storage=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.bundle.create bundle_name=value, bundle_description=value, image_id=value, compute_type=value, user_storage=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="create_workspace_bundle",
        op_kwargs={
            "BundleName": bundle_name,
            "BundleDescription": bundle_description,
            "ImageId": image_id,
            "ComputeType": compute_type,
            "UserStorage": user_storage,
            "RootStorage": root_storage,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, bundle_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified WorkSpace bundle. For more information about deleting WorkSpace bundles, see  Delete a Custom WorkSpaces Bundle or Image.

    Args:
        bundle_id(str, optional): The identifier of the bundle. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.bundle.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.bundle.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="delete_workspace_bundle",
        op_kwargs={"BundleId": bundle_id},
    )


async def describe_all(
    hub, ctx, bundle_ids: List = None, owner: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes the available WorkSpace bundles. You can filter the results using either bundle ID or owner, but not both.

    Args:
        bundle_ids(List, optional): The identifiers of the bundles. You cannot combine this parameter with any other filter. Defaults to None.
        owner(str, optional): The owner of the bundles. You cannot combine this parameter with any other filter. To describe the bundles provided by AWS, specify AMAZON. To describe the bundles that belong to your account, don't specify a value. Defaults to None.
        next_token(str, optional): The token for the next set of results. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.bundle.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.bundle.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_workspace_bundles",
        op_kwargs={"BundleIds": bundle_ids, "Owner": owner, "NextToken": next_token},
    )


async def update(hub, ctx, bundle_id: str = None, image_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a WorkSpace bundle with a new image. For more information about updating WorkSpace bundles, see  Update a Custom WorkSpaces Bundle.  Existing WorkSpaces aren't automatically updated when you update the bundle that they're based on. To update existing WorkSpaces that are based on a bundle that you've updated, you must either rebuild the WorkSpaces or delete and recreate them.

    Args:
        bundle_id(str, optional): The identifier of the bundle. Defaults to None.
        image_id(str, optional): The identifier of the image. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.bundle.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.bundle.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="update_workspace_bundle",
        op_kwargs={"BundleId": bundle_id, "ImageId": image_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def allocate(
    hub,
    ctx,
    domain: str = None,
    address: str = None,
    public_ipv4_pool: str = None,
    network_border_group: str = None,
    customer_owned_ipv4_pool: str = None,
    dry_run: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Allocates an Elastic IP address to your Amazon Web Services account. After you allocate the Elastic IP address you can associate it with an instance or network interface. After you release an Elastic IP address, it is released to the IP address pool and can be allocated to a different Amazon Web Services account. You can allocate an Elastic IP address from an address pool owned by Amazon Web Services or from an address pool created from a public IPv4 address range that you have brought to Amazon Web Services for use with your Amazon Web Services resources using bring your own IP addresses (BYOIP). For more information, see Bring Your Own IP Addresses (BYOIP) in the Amazon Elastic Compute Cloud User Guide. [EC2-VPC] If you release an Elastic IP address, you might be able to recover it. You cannot recover an Elastic IP address that you released after it is allocated to another Amazon Web Services account. You cannot recover an Elastic IP address for EC2-Classic. To attempt to recover an Elastic IP address that you released, specify it in this operation. An Elastic IP address is for use either in the EC2-Classic platform or in a VPC. By default, you can allocate 5 Elastic IP addresses for EC2-Classic per Region and 5 Elastic IP addresses for EC2-VPC per Region. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. You can allocate a carrier IP address which is a public IP address from a telecommunication carrier, to a network interface which resides in a subnet in a Wavelength Zone (for example an EC2 instance).

    Args:
        domain(str, optional): Indicates whether the Elastic IP address is for use with instances in a VPC or instances in EC2-Classic. Default: If the Region supports EC2-Classic, the default is standard. Otherwise, the default is vpc. Defaults to None.
        address(str, optional): [EC2-VPC] The Elastic IP address to recover or an IPv4 address from an address pool. Defaults to None.
        public_ipv4_pool(str, optional): The ID of an address pool that you own. Use this parameter to let Amazon EC2 select an address from the address pool. To specify a specific address from the address pool, use the Address parameter instead. Defaults to None.
        network_border_group(str, optional):  A unique set of Availability Zones, Local Zones, or Wavelength Zones from which AWS advertises IP addresses. Use this parameter to limit the IP address to this location. IP addresses cannot move between network border groups. Use DescribeAvailabilityZones to view the network border groups.  You cannot use a network border group with EC2 Classic. If you attempt this operation on EC2 classic, you will receive an InvalidParameterCombination error. For more information, see Error Codes. . Defaults to None.
        customer_owned_ipv4_pool(str, optional): The ID of a customer-owned address pool. Use this parameter to let Amazon EC2 select an address from the address pool. Alternatively, specify a specific address from the address pool. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        tag_specifications(List, optional): The tags to assign to the Elastic IP address. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.init.allocate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.init.allocate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="allocate_address",
        op_kwargs={
            "Domain": domain,
            "Address": address,
            "PublicIpv4Pool": public_ipv4_pool,
            "NetworkBorderGroup": network_border_group,
            "CustomerOwnedIpv4Pool": customer_owned_ipv4_pool,
            "DryRun": dry_run,
            "TagSpecifications": tag_specifications,
        },
    )


async def associate(
    hub,
    ctx,
    allocation_id: str = None,
    instance_id: str = None,
    public_ip: str = None,
    allow_reassociation: bool = None,
    dry_run: bool = None,
    network_interface_id: str = None,
    private_ip_address: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates an Elastic IP address, or carrier IP address (for instances that are in subnets in Wavelength Zones) with an instance or a network interface. Before you can use an Elastic IP address, you must allocate it to your account. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. [EC2-Classic, VPC in an EC2-VPC-only account] If the Elastic IP address is already associated with a different instance, it is disassociated from that instance and associated with the specified instance. If you associate an Elastic IP address with an instance that has an existing Elastic IP address, the existing address is disassociated from the instance, but remains allocated to your account. [VPC in an EC2-Classic account] If you don't specify a private IP address, the Elastic IP address is associated with the primary IP address. If the Elastic IP address is already associated with a different instance or a network interface, you get an error unless you allow reassociation. You cannot associate an Elastic IP address with an instance or network interface that has an existing Elastic IP address. [Subnets in Wavelength Zones] You can associate an IP address from the telecommunication carrier to the instance or network interface.  You cannot associate an Elastic IP address with an interface in a different network border group.  This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error, and you may be charged for each time the Elastic IP address is remapped to the same instance. For more information, see the Elastic IP Addresses section of Amazon EC2 Pricing.

    Args:
        allocation_id(str, optional): [EC2-VPC] The allocation ID. This is required for EC2-VPC. Defaults to None.
        instance_id(str, optional): The ID of the instance. The instance must have exactly one attached network interface. For EC2-VPC, you can specify either the instance ID or the network interface ID, but not both. For EC2-Classic, you must specify an instance ID and the instance must be in the running state. Defaults to None.
        public_ip(str, optional): [EC2-Classic] The Elastic IP address to associate with the instance. This is required for EC2-Classic. Defaults to None.
        allow_reassociation(bool, optional): [EC2-VPC] For a VPC in an EC2-Classic account, specify true to allow an Elastic IP address that is already associated with an instance or network interface to be reassociated with the specified instance or network interface. Otherwise, the operation fails. In a VPC in an EC2-VPC-only account, reassociation is automatic, therefore you can specify false to ensure the operation fails if the Elastic IP address is already associated with another resource. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_interface_id(str, optional): [EC2-VPC] The ID of the network interface. If the instance has more than one network interface, you must specify a network interface ID. For EC2-VPC, you can specify either the instance ID or the network interface ID, but not both. . Defaults to None.
        private_ip_address(str, optional): [EC2-VPC] The primary or secondary private IP address to associate with the Elastic IP address. If no private IP address is specified, the Elastic IP address is associated with the primary private IP address. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.init.associate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.init.associate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_address",
        op_kwargs={
            "AllocationId": allocation_id,
            "InstanceId": instance_id,
            "PublicIp": public_ip,
            "AllowReassociation": allow_reassociation,
            "DryRun": dry_run,
            "NetworkInterfaceId": network_interface_id,
            "PrivateIpAddress": private_ip_address,
        },
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    public_ips: List = None,
    allocation_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Elastic IP addresses or all of your Elastic IP addresses. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.

    Args:
        filters(List, optional): One or more filters. Filter names and values are case-sensitive.    allocation-id - [EC2-VPC] The allocation ID for the address.    association-id - [EC2-VPC] The association ID for the address.    domain - Indicates whether the address is for use in EC2-Classic (standard) or in a VPC (vpc).    instance-id - The ID of the instance the address is associated with, if any.    network-border-group - A unique set of Availability Zones, Local Zones, or Wavelength Zones from where Amazon Web Services advertises IP addresses.     network-interface-id - [EC2-VPC] The ID of the network interface that the address is associated with, if any.    network-interface-owner-id - The Amazon Web Services account ID of the owner.    private-ip-address - [EC2-VPC] The private IP address associated with the Elastic IP address.    public-ip - The Elastic IP address, or the carrier IP address.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        public_ips(List, optional): One or more Elastic IP addresses. Default: Describes all your Elastic IP addresses. Defaults to None.
        allocation_ids(List, optional): [EC2-VPC] Information about the allocation IDs. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_addresses",
        op_kwargs={
            "Filters": filters,
            "PublicIps": public_ips,
            "AllocationIds": allocation_ids,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub, ctx, association_id: str = None, public_ip: str = None, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Disassociates an Elastic IP address from the instance or network interface it's associated with. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error.

    Args:
        association_id(str, optional): [EC2-VPC] The association ID. Required for EC2-VPC. Defaults to None.
        public_ip(str, optional): [EC2-Classic] The Elastic IP address. Required for EC2-Classic. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.init.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.init.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_address",
        op_kwargs={
            "AssociationId": association_id,
            "PublicIp": public_ip,
            "DryRun": dry_run,
        },
    )


async def release(
    hub,
    ctx,
    allocation_id: str = None,
    public_ip: str = None,
    network_border_group: str = None,
    dry_run: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Releases the specified Elastic IP address. [EC2-Classic, default VPC] Releasing an Elastic IP address automatically disassociates it from any instance that it's associated with. To disassociate an Elastic IP address without releasing it, use DisassociateAddress. [Nondefault VPC] You must use DisassociateAddress to disassociate the Elastic IP address before you can release it. Otherwise, Amazon EC2 returns an error (InvalidIPAddress.InUse). After releasing an Elastic IP address, it is released to the IP address pool. Be sure to update your DNS records and any servers or devices that communicate with the address. If you attempt to release an Elastic IP address that you already released, you'll get an AuthFailure error if the address is already allocated to another Amazon Web Services account. [EC2-VPC] After you release an Elastic IP address for use in a VPC, you might be able to recover it. For more information, see AllocateAddress.

    Args:
        allocation_id(str, optional): [EC2-VPC] The allocation ID. Required for EC2-VPC. Defaults to None.
        public_ip(str, optional): [EC2-Classic] The Elastic IP address. Required for EC2-Classic. Defaults to None.
        network_border_group(str, optional): The set of Availability Zones, Local Zones, or Wavelength Zones from which AWS advertises IP addresses. If you provide an incorrect network border group, you will receive an InvalidAddress.NotFound error. For more information, see Error Codes.  You cannot use a network border group with EC2 Classic. If you attempt this operation on EC2 classic, you will receive an InvalidParameterCombination error. For more information, see Error Codes. . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.init.release(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.init.release
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="release_address",
        op_kwargs={
            "AllocationId": allocation_id,
            "PublicIp": public_ip,
            "NetworkBorderGroup": network_border_group,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Return the tags applied to an AWS Elastic Beanstalk resource. The response contains a list of tag key-value pairs. Elastic Beanstalk supports tagging of all of its resources. For details about resource tagging, see Tagging Application Resources.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resouce for which a tag list is requested. Must be the ARN of an Elastic Beanstalk resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def update(
    hub, ctx, resource_arn: str, tags_to_add: List = None, tags_to_remove: List = None
) -> None:
    r"""
    **Autogenerated function**

    Update the list of tags applied to an AWS Elastic Beanstalk resource. Two lists can be passed: TagsToAdd for tags to add or update, and TagsToRemove. Elastic Beanstalk supports tagging of all of its resources. For details about resource tagging, see Tagging Application Resources. If you create a custom IAM user policy to control permission to this operation, specify one of the following two virtual actions (or both) instead of the API operation name:  elasticbeanstalk:AddTags  Controls permission to call UpdateTagsForResource and pass a list of tags to add in the TagsToAdd parameter.  elasticbeanstalk:RemoveTags  Controls permission to call UpdateTagsForResource and pass a list of tag keys to remove in the TagsToRemove parameter.   For details about creating a custom user policy, see Creating a Custom User Policy.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resouce to be updated. Must be the ARN of an Elastic Beanstalk resource.
        tags_to_add(List, optional): A list of tags to add or update. If a key of an existing tag is added, the tag's value is updated. Specify at least one of these parameters: TagsToAdd, TagsToRemove. Defaults to None.
        tags_to_remove(List, optional): A list of tag keys to remove. If a tag key doesn't exist, it is silently ignored. Specify at least one of these parameters: TagsToAdd, TagsToRemove. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.tags_for_resource.update(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.tags_for_resource.update resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="update_tags_for_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "TagsToAdd": tags_to_add,
            "TagsToRemove": tags_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, attachment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the attachment that has the specified ID. Attachments can include screenshots, error logs, or other files that describe your issue. Attachment IDs are generated by the case management system when you add an attachment to a case or case communication. Attachment IDs are returned in the AttachmentDetails objects that are returned by the DescribeCommunications operation.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        attachment_id(str): The ID of the attachment to return. Attachment IDs are returned by the DescribeCommunications operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.attachment.init.describe(ctx, attachment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.attachment.init.describe attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_attachment",
        op_kwargs={"attachmentId": attachment_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    bucket: str,
    delimiter: str = None,
    encoding_type: str = None,
    key_marker: str = None,
    max_keys: int = None,
    prefix: str = None,
    version_id_marker: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about all versions of the objects in a bucket. You can also use request parameters as selection criteria to return metadata about a subset of all the object versions.   To use this operation, you must have permissions to perform the s3:ListBucketVersions action. Be aware of the name difference.     A 200 OK response can contain valid or invalid XML. Make sure to design your application to parse the contents of the response and handle it appropriately.  To use this operation, you must have READ access to the bucket. This action is not supported by Amazon S3 on Outposts. The following operations are related to ListObjectVersions:    ListObjectsV2     GetObject     PutObject     DeleteObject

    Args:
        bucket(str): The bucket name that contains the objects. .
        delimiter(str, optional): A delimiter is a character that you specify to group keys. All keys that contain the same string between the prefix and the first occurrence of the delimiter are grouped under a single result element in CommonPrefixes. These groups are counted as one result against the max-keys limitation. These keys are not returned elsewhere in the response. Defaults to None.
        encoding_type(str, optional): Requests Amazon S3 to encode the object keys in the response and specifies the encoding method to use. An object key may contain any Unicode character; however, XML 1.0 parser cannot parse some characters, such as characters with an ASCII value from 0 to 10. For characters that are not supported in XML 1.0, you can add this parameter to request that Amazon S3 encode the keys in the response. Defaults to None.
        key_marker(str, optional): Specifies the key to start with when listing objects in a bucket. Defaults to None.
        max_keys(int, optional): Sets the maximum number of keys returned in the response. By default the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more. If additional keys satisfy the search criteria, but were not returned because max-keys was exceeded, the response contains <isTruncated>true</isTruncated>. To return the additional keys, see key-marker and version-id-marker. Defaults to None.
        prefix(str, optional): Use this parameter to select only those keys that begin with the specified prefix. You can use prefixes to separate a bucket into different groupings of keys. (You can think of using prefix to make groups in the same way you'd use a folder in a file system.) You can use prefix with delimiter to roll up numerous objects into a single result under CommonPrefixes. . Defaults to None.
        version_id_marker(str, optional): Specifies the object version you want to start listing from. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.object_.version.list_all(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.object_.version.list_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="list_object_versions",
        op_kwargs={
            "Bucket": bucket,
            "Delimiter": delimiter,
            "EncodingType": encoding_type,
            "KeyMarker": key_marker,
            "MaxKeys": max_keys,
            "Prefix": prefix,
            "VersionIdMarker": version_id_marker,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    index_id: str,
    name: str,
    role_arn: str,
    source_s3_path: Dict,
    description: str = None,
    tags: List = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a thesaurus for an index. The thesaurus contains a list of synonyms in Solr format.

    Args:
        index_id(str): The unique identifier of the index for the new thesaurus. .
        name(str): The name for the new thesaurus.
        description(str, optional): The description for the new thesaurus. Defaults to None.
        role_arn(str): An AWS Identity and Access Management (IAM) role that gives Amazon Kendra permissions to access thesaurus file specified in SourceS3Path. .
        tags(List, optional): A list of key-value pairs that identify the thesaurus. You can use the tags to identify and organize your resources and to control access to resources. . Defaults to None.
        source_s3_path(Dict): The thesaurus file Amazon S3 source path. .
        client_token(str, optional): A token that you provide to identify the request to create a thesaurus. Multiple calls to the CreateThesaurus operation with the same client token will create only one index. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.thesaurus.create(
                ctx, index_id=value, name=value, role_arn=value, source_s3_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.thesaurus.create index_id=value, name=value, role_arn=value, source_s3_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="create_thesaurus",
        op_kwargs={
            "IndexId": index_id,
            "Name": name,
            "Description": description,
            "RoleArn": role_arn,
            "Tags": tags,
            "SourceS3Path": source_s3_path,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, id_: str, index_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing Amazon Kendra thesaurus.

    Args:
        id_(str): The identifier of the thesaurus to delete.
        index_id(str): The identifier of the index associated with the thesaurus to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.thesaurus.delete(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.thesaurus.delete id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="delete_thesaurus",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )


async def describe(hub, ctx, id_: str, index_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing Amazon Kendra thesaurus.

    Args:
        id_(str): The identifier of the thesaurus to describe.
        index_id(str): The identifier of the index associated with the thesaurus to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.thesaurus.describe(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.thesaurus.describe id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="describe_thesaurus",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )


async def update(
    hub,
    ctx,
    id_: str,
    index_id: str,
    name: str = None,
    description: str = None,
    role_arn: str = None,
    source_s3_path: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a thesaurus file associated with an index.

    Args:
        id_(str): The identifier of the thesaurus to update.
        name(str, optional): The updated name of the thesaurus. Defaults to None.
        index_id(str): The identifier of the index associated with the thesaurus to update.
        description(str, optional): The updated description of the thesaurus. Defaults to None.
        role_arn(str, optional): The updated role ARN of the thesaurus. Defaults to None.
        source_s3_path(Dict, optional): Information required to find a specific file in an Amazon S3 bucket. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.thesaurus.update(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.thesaurus.update id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="update_thesaurus",
        op_kwargs={
            "Id": id_,
            "Name": name,
            "IndexId": index_id,
            "Description": description,
            "RoleArn": role_arn,
            "SourceS3Path": source_s3_path,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags that are assigned to an Amazon Cognito user pool. A tag is a label that you can apply to user pools to categorize and manage them in different ways, such as by purpose, owner, environment, or other criteria. You can use this action up to 10 times per second, per account.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the user pool that the tags are assigned to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, identity_pool_id: str, identity_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets usage information for an identity, including number of datasets and data usage. This API can be called with temporary user credentials provided by Cognito Identity or with developer credentials.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        identity_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.identity.usage.describe(
                ctx, identity_pool_id=value, identity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.identity.usage.describe identity_pool_id=value, identity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="describe_identity_usage",
        op_kwargs={"IdentityPoolId": identity_pool_id, "IdentityId": identity_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    existing_image_name: str,
    new_image_name: str,
    new_image_description: str = None,
    new_image_display_name: str = None,
    new_image_tags: Dict = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new image with the latest Windows operating system updates, driver updates, and AppStream 2.0 agent software. For more information, see the "Update an Image by Using Managed AppStream 2.0 Image Updates" section in Administer Your AppStream 2.0 Images, in the Amazon AppStream 2.0 Administration Guide.

    Args:
        existing_image_name(str): The name of the image to update.
        new_image_name(str): The name of the new image. The name must be unique within the AWS account and Region.
        new_image_description(str, optional): The description to display for the new image. Defaults to None.
        new_image_display_name(str, optional): The name to display for the new image. Defaults to None.
        new_image_tags(Dict, optional): The tags to associate with the new image. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.  Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:  _ . : / = + \ - @ If you do not specify a value, the value is set to an empty string. For more information about tags, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        dry_run(bool, optional): Indicates whether to display the status of image update availability before AppStream 2.0 initiates the process of creating a new updated image. If this value is set to true, AppStream 2.0 displays whether image updates are available. If this value is set to false, AppStream 2.0 initiates the process of creating a new updated image without displaying whether image updates are available. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.updated_image.create(
                ctx, existing_image_name=value, new_image_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.updated_image.create existing_image_name=value, new_image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_updated_image",
        op_kwargs={
            "existingImageName": existing_image_name,
            "newImageName": new_image_name,
            "newImageDescription": new_image_description,
            "newImageDisplayName": new_image_display_name,
            "newImageTags": new_image_tags,
            "dryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, type_configuration_identifiers: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns configuration data for the specified CloudFormation extensions, from the CloudFormation registry for the account and region. For more information, see Configuring extensions at the account level in the CloudFormation User Guide.

    Args:
        type_configuration_identifiers(List): The list of identifiers for the desired extension configurations.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.describe_type_configuration.batch(
                ctx, type_configuration_identifiers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.describe_type_configuration.batch type_configuration_identifiers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="batch_describe_type_configurations",
        op_kwargs={"TypeConfigurationIdentifiers": type_configuration_identifiers},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(hub, ctx, handshake_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Sends a response to the originator of a handshake agreeing to the action proposed by the handshake request. This operation can be called only by the following principals when they also have the relevant IAM permissions:    Invitation to join or Approve all features request handshakes: only a principal from the member account. The user who calls the API for an invitation to join must have the organizations:AcceptHandshake permission. If you enabled all features in the organization, the user must also have the iam:CreateServiceLinkedRole permission so that AWS Organizations can create the required service-linked role named AWSServiceRoleForOrganizations. For more information, see AWS Organizations and Service-Linked Roles in the AWS Organizations User Guide.    Enable all features final confirmation handshake: only a principal from the management account. For more information about invitations, see Inviting an AWS Account to Join Your Organization in the AWS Organizations User Guide. For more information about requests to enable all features in the organization, see Enabling All Features in Your Organization in the AWS Organizations User Guide.    After you accept a handshake, it continues to appear in the results of relevant APIs for only 30 days. After that, it's deleted.

    Args:
        handshake_id(str): The unique identifier (ID) of the handshake that you want to accept. The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.handshake.init.accept(ctx, handshake_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.handshake.init.accept handshake_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="accept_handshake",
        op_kwargs={"HandshakeId": handshake_id},
    )


async def cancel(hub, ctx, handshake_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a handshake. Canceling a handshake sets the handshake state to CANCELED. This operation can be called only from the account that originated the handshake. The recipient of the handshake can't cancel it, but can use DeclineHandshake instead. After a handshake is canceled, the recipient can no longer respond to that handshake. After you cancel a handshake, it continues to appear in the results of relevant APIs for only 30 days. After that, it's deleted.

    Args:
        handshake_id(str): The unique identifier (ID) of the handshake that you want to cancel. You can get the ID from the ListHandshakesForOrganization operation. The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.handshake.init.cancel(ctx, handshake_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.handshake.init.cancel handshake_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="cancel_handshake",
        op_kwargs={"HandshakeId": handshake_id},
    )


async def decline(hub, ctx, handshake_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Declines a handshake request. This sets the handshake state to DECLINED and effectively deactivates the request. This operation can be called only from the account that received the handshake. The originator of the handshake can use CancelHandshake instead. The originator can't reactivate a declined request, but can reinitiate the process with a new handshake request. After you decline a handshake, it continues to appear in the results of relevant APIs for only 30 days. After that, it's deleted.

    Args:
        handshake_id(str): The unique identifier (ID) of the handshake that you want to decline. You can get the ID from the ListHandshakesForAccount operation. The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.handshake.init.decline(ctx, handshake_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.handshake.init.decline handshake_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="decline_handshake",
        op_kwargs={"HandshakeId": handshake_id},
    )


async def describe(hub, ctx, handshake_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a previously requested handshake. The handshake ID comes from the response to the original InviteAccountToOrganization operation that generated the handshake. You can access handshakes that are ACCEPTED, DECLINED, or CANCELED for only 30 days after they change to that state. They're then deleted and no longer accessible. This operation can be called from any account in the organization.

    Args:
        handshake_id(str): The unique identifier (ID) of the handshake that you want information about. You can get the ID from the original call to InviteAccountToOrganization, or from a call to ListHandshakesForAccount or ListHandshakesForOrganization. The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.handshake.init.describe(ctx, handshake_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.handshake.init.describe handshake_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="describe_handshake",
        op_kwargs={"HandshakeId": handshake_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"continue_": "continue"}


async def continue_(
    hub,
    ctx,
    stack_name: str,
    role_arn: str = None,
    resources_to_skip: List = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For a specified stack that is in the UPDATE_ROLLBACK_FAILED state, continues rolling it back to the UPDATE_ROLLBACK_COMPLETE state. Depending on the cause of the failure, you can manually  fix the error and continue the rollback. By continuing the rollback, you can return your stack to a working state (the UPDATE_ROLLBACK_COMPLETE state), and then try to update the stack again. A stack goes into the UPDATE_ROLLBACK_FAILED state when CloudFormation cannot roll back all changes after a failed stack update. For example, you might have a stack that is rolling back to an old database instance that was deleted outside of CloudFormation. Because CloudFormation doesn't know the database was deleted, it assumes that the database instance still exists and attempts to roll back to it, causing the update rollback to fail.

    Args:
        stack_name(str): The name or the unique ID of the stack that you want to continue rolling back.  Don't specify the name of a nested stack (a stack that was created by using the AWS::CloudFormation::Stack resource). Instead, use this operation on the parent stack (the stack that contains the AWS::CloudFormation::Stack resource). .
        role_arn(str, optional): The Amazon Resource Name (ARN) of an Identity and Access Management (IAM) role that CloudFormation assumes to roll back the stack. CloudFormation uses the role's credentials to make calls on your behalf. CloudFormation always uses this role for all future operations on the stack. As long as users have permission to operate on the stack, CloudFormation uses this role even if the users don't have permission to pass it. Ensure that the role grants least privilege. If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials. Defaults to None.
        resources_to_skip(List, optional): A list of the logical IDs of the resources that CloudFormation skips during the continue update rollback operation. You can specify only resources that are in the UPDATE_FAILED state because a rollback failed. You can't specify resources that are in the UPDATE_FAILED state for other reasons, for example, because an update was cancelled. To check why a resource update failed, use the DescribeStackResources action, and view the resource status reason.   Specify this property to skip rolling back resources that CloudFormation can't successfully roll back. We recommend that you  troubleshoot resources before skipping them. CloudFormation sets the status of the specified resources to UPDATE_COMPLETE and continues to roll back the stack. After the rollback is complete, the state of the skipped resources will be inconsistent with the state of the resources in the stack template. Before performing another stack update, you must update the stack or resources to be consistent with each other. If you don't, subsequent stack updates might fail, and the stack will become unrecoverable.   Specify the minimum number of resources required to successfully roll back your stack. For example, a failed resource update might cause dependent resources to fail. In this case, it might not be necessary to skip the dependent resources.  To skip resources that are part of nested stacks, use the following format: NestedStackName.ResourceLogicalID. If you want to specify the logical ID of a stack resource (Type: AWS::CloudFormation::Stack) in the ResourcesToSkip list, then its corresponding embedded stack must be in one of the following states: DELETE_IN_PROGRESS, DELETE_COMPLETE, or DELETE_FAILED.   Don't confuse a child stack's name with its corresponding logical ID defined in the parent stack. For an example of a continue update rollback operation with nested stacks, see Using ResourcesToSkip to recover a nested stacks hierarchy.  . Defaults to None.
        client_request_token(str, optional): A unique identifier for this ContinueUpdateRollback request. Specify this token if you plan to retry requests so that CloudFormationknows that you're not attempting to continue the rollback to a stack with the same name. You might retry ContinueUpdateRollback requests to ensure that CloudFormation successfully received them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.update.rollback.continue(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.update.rollback.continue stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="continue_update_rollback",
        op_kwargs={
            "StackName": stack_name,
            "RoleARN": role_arn,
            "ResourcesToSkip": resources_to_skip,
            "ClientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def promote(
    hub,
    ctx,
    db_instance_identifier: str,
    backup_retention_period: int = None,
    preferred_backup_window: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Promotes a read replica DB instance to a standalone DB instance.    Backup duration is a function of the amount of changes to the database since the previous backup. If you plan to promote a read replica to a standalone instance, we recommend that you enable backups and complete at least one backup prior to promotion. In addition, a read replica cannot be promoted to a standalone instance when it is in the backing-up status. If you have enabled backups on your read replica, configure the automated backup window so that daily backups do not interfere with read replica promotion.   This command doesn't apply to Aurora MySQL and Aurora PostgreSQL.

    Args:
        db_instance_identifier(str): The DB instance identifier. This value is stored as a lowercase string. Constraints:   Must match the identifier of an existing read replica DB instance.   Example: mydbinstance .
        backup_retention_period(int, optional): The number of days for which automated backups are retained. Setting this parameter to a positive number enables backups. Setting this parameter to 0 disables automated backups. Default: 1 Constraints:   Must be a value from 0 to 35.   Can't be set to 0 if the DB instance is a source to read replicas.  . Defaults to None.
        preferred_backup_window(str, optional):  The daily time range during which automated backups are created if automated backups are enabled, using the BackupRetentionPeriod parameter.   The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region. To see the time blocks available, see  Adjusting the Preferred Maintenance Window in the Amazon RDS User Guide.  Constraints:   Must be in the format hh24:mi-hh24:mi.   Must be in Universal Coordinated Time (UTC).   Must not conflict with the preferred maintenance window.   Must be at least 30 minutes.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.read_replica.init.promote(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.read_replica.init.promote db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="promote_read_replica",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "BackupRetentionPeriod": backup_retention_period,
            "PreferredBackupWindow": preferred_backup_window,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, fleet_id: str, actions: List, location: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Resumes certain types of activity on fleet instances that were suspended with StopFleetActions. For multi-location fleets, fleet actions are managed separately for each location. Currently, this operation is used to restart a fleet's auto-scaling activity. This operation can be used in the following ways:    To restart actions on instances in the fleet's home Region, provide a fleet ID and the type of actions to resume.    To restart actions on instances in one of the fleet's remote locations, provide a fleet ID, a location name, and the type of actions to resume.    If successful, GameLift once again initiates scaling events as triggered by the fleet's scaling policies. If actions on the fleet location were never stopped, this operation will have no effect. You can view a fleet's stopped actions using DescribeFleetAttributes or DescribeFleetLocationAttributes.  Learn more   Setting up GameLift fleets   Related actions   CreateFleet | UpdateFleetCapacity | PutScalingPolicy | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetLocationAttributes | UpdateFleetAttributes | StopFleetActions | DeleteFleet | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to restart actions on. You can use either the fleet ID or ARN value.
        actions(List): List of actions to restart on the fleet.
        location(str, optional): The fleet location to restart fleet actions for. Specify a location in the form of an AWS Region code, such as us-west-2. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.action.start(ctx, fleet_id=value, actions=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.action.start fleet_id=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="start_fleet_actions",
        op_kwargs={"FleetId": fleet_id, "Actions": actions, "Location": location},
    )


async def stop(hub, ctx, fleet_id: str, actions: List, location: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Suspends certain types of activity in a fleet location. Currently, this operation is used to stop auto-scaling activity. For multi-location fleets, fleet actions are managed separately for each location.  Stopping fleet actions has several potential purposes. It allows you to temporarily stop auto-scaling activity but retain your scaling policies for use in the future. For multi-location fleets, you can set up fleet-wide auto-scaling, and then opt out of it for certain locations.  This operation can be used in the following ways:    To stop actions on instances in the fleet's home Region, provide a fleet ID and the type of actions to suspend.    To stop actions on instances in one of the fleet's remote locations, provide a fleet ID, a location name, and the type of actions to suspend.    If successful, GameLift no longer initiates scaling events except in response to manual changes using UpdateFleetCapacity. You can view a fleet's stopped actions using DescribeFleetAttributes or DescribeFleetLocationAttributes. Suspended activity can be restarted using StartFleetActions.  Learn more   Setting up GameLift Fleets   Related actions   CreateFleet | UpdateFleetCapacity | PutScalingPolicy | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetLocationAttributes | UpdateFleetAttributes | StopFleetActions | DeleteFleet | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to stop actions on. You can use either the fleet ID or ARN value.
        actions(List): List of actions to suspend on the fleet. .
        location(str, optional): The fleet location to stop fleet actions for. Specify a location in the form of an AWS Region code, such as us-west-2. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.action.stop(ctx, fleet_id=value, actions=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.action.stop fleet_id=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="stop_fleet_actions",
        op_kwargs={"FleetId": fleet_id, "Actions": actions, "Location": location},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, core_device_thing_name: str, entries: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Associate a list of client devices with a core device. Use this API operation to specify which client devices can discover a core device through cloud discovery. With cloud discovery, client devices connect to IoT Greengrass to retrieve associated core devices' connectivity information and certificates. For more information, see Configure cloud discovery in the IoT Greengrass V2 Developer Guide.  Client devices are local IoT devices that connect to and communicate with an IoT Greengrass core device over MQTT. You can connect client devices to a core device to sync MQTT messages and data to Amazon Web Services IoT Core and interact with client devices in Greengrass components. For more information, see Interact with local IoT devices in the IoT Greengrass V2 Developer Guide.

    Args:
        entries(List, optional): The list of client devices to associate. Defaults to None.
        core_device_thing_name(str): The name of the core device. This is also the name of the IoT thing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.associate_client_device_with_core_device.batch(
                ctx, core_device_thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.associate_client_device_with_core_device.batch core_device_thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="batch_associate_client_device_with_core_device",
        op_kwargs={"entries": entries, "coreDeviceThingName": core_device_thing_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, meeting_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags applied to an Amazon Chime SDK meeting resource.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.meeting.tag.list_all(ctx, meeting_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.meeting.tag.list_all meeting_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_meeting_tags",
        op_kwargs={"MeetingId": meeting_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def execute(
    hub,
    ctx,
    aws_secret_store_arn: str,
    db_cluster_or_instance_arn: str,
    sql_statements: str,
    database: str = None,
    schema: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs one or more SQL statements.  This operation is deprecated. Use the BatchExecuteStatement or ExecuteStatement operation.

    Args:
        aws_secret_store_arn(str): The Amazon Resource Name (ARN) of the secret that enables access to the DB cluster.
        database(str, optional): The name of the database. Defaults to None.
        db_cluster_or_instance_arn(str): The ARN of the Aurora Serverless DB cluster.
        schema(str, optional): The name of the database schema. Defaults to None.
        sql_statements(str): One or more SQL statements to run on the DB cluster. You can separate SQL statements from each other with a semicolon (;). Any valid SQL statement is permitted, including data definition, data manipulation, and commit statements. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds_data.sql.execute(
                ctx,
                aws_secret_store_arn=value,
                db_cluster_or_instance_arn=value,
                sql_statements=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds_data.sql.execute aws_secret_store_arn=value, db_cluster_or_instance_arn=value, sql_statements=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds-data",
        operation="execute_sql",
        op_kwargs={
            "awsSecretStoreArn": aws_secret_store_arn,
            "database": database,
            "dbClusterOrInstanceArn": db_cluster_or_instance_arn,
            "schema": schema,
            "sqlStatements": sql_statements,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def download(
    hub,
    ctx,
    db_instance_identifier: str,
    log_file_name: str,
    marker: str = None,
    number_of_lines: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Downloads all or a portion of the specified log file, up to 1 MB in size.

    Args:
        db_instance_identifier(str): The customer-assigned name of the DB instance that contains the log files you want to list. Constraints:   Must match the identifier of an existing DBInstance.  .
        log_file_name(str): The name of the log file to be downloaded.
        marker(str, optional): The pagination token provided in the previous request or "0". If the Marker parameter is specified the response includes only records beyond the marker until the end of the file or up to NumberOfLines. Defaults to None.
        number_of_lines(int, optional): The number of lines to download. If the number of lines specified results in a file over 1 MB in size, the file is truncated at 1 MB in size. If the NumberOfLines parameter is specified, then the block of lines returned can be from the beginning or the end of the log file, depending on the value of the Marker parameter.   If neither Marker or NumberOfLines are specified, the entire log file is returned up to a maximum of 10000 lines, starting with the most recent log entries first.   If NumberOfLines is specified and Marker isn't specified, then the most recent lines from the end of the log file are returned.   If Marker is specified as "0", then the specified number of lines from the beginning of the log file are returned.   You can download the log file in blocks of lines by specifying the size of the block using the NumberOfLines parameter, and by specifying a value of "0" for the Marker parameter in your first request. Include the Marker value returned in the response as the Marker value for the next request, continuing until the AdditionalDataPending response element returns false.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.log_file.portion.download(
                ctx, db_instance_identifier=value, log_file_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.log_file.portion.download db_instance_identifier=value, log_file_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="download_db_log_file_portion",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "LogFileName": log_file_name,
            "Marker": marker,
            "NumberOfLines": number_of_lines,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gives a description of the Time to Live (TTL) status on the specified table.

    Args:
        table_name(str): The name of the table to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.time_to_live.describe(ctx, table_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.time_to_live.describe table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_time_to_live",
        op_kwargs={"TableName": table_name},
    )


async def update(hub, ctx, table_name: str, time_to_live_specification: Dict) -> Dict:
    r"""
    **Autogenerated function**

    The UpdateTimeToLive method enables or disables Time to Live (TTL) for the specified table. A successful UpdateTimeToLive call returns the current TimeToLiveSpecification. It can take up to one hour for the change to fully process. Any additional UpdateTimeToLive calls for the same table during this one hour duration result in a ValidationException.  TTL compares the current time in epoch time format to the time stored in the TTL attribute of an item. If the epoch time value stored in the attribute is less than the current time, the item is marked as expired and subsequently deleted.   The epoch time format is the number of seconds elapsed since 12:00:00 AM January 1, 1970 UTC.   DynamoDB deletes expired items on a best-effort basis to ensure availability of throughput for other data operations.   DynamoDB typically deletes expired items within two days of expiration. The exact duration within which an item gets deleted after expiration is specific to the nature of the workload. Items that have expired and not been deleted will still show up in reads, queries, and scans.  As items are deleted, they are removed from any local secondary index and global secondary index immediately in the same eventually consistent way as a standard delete operation. For more information, see Time To Live in the Amazon DynamoDB Developer Guide.

    Args:
        table_name(str): The name of the table to be configured.
        time_to_live_specification(Dict): Represents the settings used to enable or disable Time to Live for the specified table.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.time_to_live.update(
                ctx, table_name=value, time_to_live_specification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.time_to_live.update table_name=value, time_to_live_specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="update_time_to_live",
        op_kwargs={
            "TableName": table_name,
            "TimeToLiveSpecification": time_to_live_specification,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    source_identifier: str = None,
    source_type: str = None,
    start_time: str = None,
    end_time: str = None,
    duration: int = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns events related to clusters, cache security groups, and cache parameter groups. You can obtain events specific to a particular cluster, cache security group, or cache parameter group by providing the name as a parameter. By default, only the events occurring within the last hour are returned; however, you can retrieve up to 14 days' worth of events if necessary.

    Args:
        source_identifier(str, optional): The identifier of the event source for which events are returned. If not specified, all sources are included in the response. Defaults to None.
        source_type(str, optional): The event source to retrieve events for. If no value is specified, all events are returned. Defaults to None.
        start_time(str, optional): The beginning of the time interval to retrieve events for, specified in ISO 8601 format.  Example: 2017-03-30T07:03:49.555Z. Defaults to None.
        end_time(str, optional): The end of the time interval for which to retrieve events, specified in ISO 8601 format.  Example: 2017-03-30T07:03:49.555Z. Defaults to None.
        duration(int, optional): The number of minutes worth of events to retrieve. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: minimum 20; maximum 100. Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.event.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.event.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_events",
        op_kwargs={
            "SourceIdentifier": source_identifier,
            "SourceType": source_type,
            "StartTime": start_time,
            "EndTime": end_time,
            "Duration": duration,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, domain_name: str) -> None:
    r"""
    **Autogenerated function**

     The CreateDomain operation creates a new domain. The domain name should be unique among the domains associated with the Access Key ID provided in the request. The CreateDomain operation may take 10 or more seconds to complete.   The client can create up to 100 domains per account.   If the client requires additional domains, go to  http://aws.amazon.com/contact-us/simpledb-limit-request/.

    Args:
        domain_name(str): The name of the domain to create. The name can range between 3 and 255 characters and can contain the following characters: a-z, A-Z, 0-9, '_', '-', and '.'.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sdb.domain.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sdb.domain.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sdb",
        operation="create_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def delete(hub, ctx, domain_name: str) -> None:
    r"""
    **Autogenerated function**

     The DeleteDomain operation deletes a domain. Any items (and their attributes) in the domain are deleted as well. The DeleteDomain operation might take 10 or more seconds to complete.

    Args:
        domain_name(str): The name of the domain to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sdb.domain.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sdb.domain.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sdb",
        operation="delete_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def list_all(
    hub, ctx, max_number_of_domains: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     The ListDomains operation lists all domains associated with the Access Key ID. It returns domain names up to the limit set by MaxNumberOfDomains. A NextToken is returned if there are more than MaxNumberOfDomains domains. Calling ListDomains successive times with the NextToken provided by the operation returns up to MaxNumberOfDomains more domain names with each successive operation call.

    Args:
        max_number_of_domains(int, optional): The maximum number of domain names you want returned. The range is 1 to 100. The default setting is 100. Defaults to None.
        next_token(str, optional): A string informing Amazon SimpleDB where to start the next list of domain names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sdb.domain.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sdb.domain.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sdb",
        operation="list_domains",
        op_kwargs={
            "MaxNumberOfDomains": max_number_of_domains,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, cloud_front_origin_access_identity_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new origin access identity. If you're using Amazon S3 for your origin, you can use an origin access identity to require users to access your content using a CloudFront URL instead of the Amazon S3 URL. For more information about how to use origin access identities, see Serving Private Content through CloudFront in the Amazon CloudFront Developer Guide.

    Args:
        cloud_front_origin_access_identity_config(Dict): The current configuration information for the identity.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cloud_front_origin_access_identity.init.create(
                ctx, cloud_front_origin_access_identity_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cloud_front_origin_access_identity.init.create cloud_front_origin_access_identity_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_cloud_front_origin_access_identity",
        op_kwargs={
            "CloudFrontOriginAccessIdentityConfig": cloud_front_origin_access_identity_config
        },
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Delete an origin access identity.

    Args:
        id_(str): The origin access identity's ID.
        if_match(str, optional): The value of the ETag header you received from a previous GET or PUT request. For example: E2QWRUHAPOMQZL. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cloud_front_origin_access_identity.init.delete(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cloud_front_origin_access_identity.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_cloud_front_origin_access_identity",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the information about an origin access identity.

    Args:
        id_(str): The identity's ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cloud_front_origin_access_identity.init.get(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cloud_front_origin_access_identity.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_cloud_front_origin_access_identity",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists origin access identities.

    Args:
        marker(str, optional): Use this when paginating results to indicate where to begin in your list of origin access identities. The results include identities in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page's response (which is also the ID of the last identity on that page). Defaults to None.
        max_items(str, optional): The maximum number of origin access identities you want in the response body. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cloud_front_origin_access_identity.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cloud_front_origin_access_identity.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_cloud_front_origin_access_identities",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub,
    ctx,
    cloud_front_origin_access_identity_config: Dict,
    id_: str,
    if_match: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an origin access identity.

    Args:
        cloud_front_origin_access_identity_config(Dict): The identity's configuration information.
        id_(str): The identity's id.
        if_match(str, optional): The value of the ETag header that you received when retrieving the identity's configuration. For example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.cloud_front_origin_access_identity.init.update(
                ctx, cloud_front_origin_access_identity_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.cloud_front_origin_access_identity.init.update cloud_front_origin_access_identity_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_cloud_front_origin_access_identity",
        op_kwargs={
            "CloudFrontOriginAccessIdentityConfig": cloud_front_origin_access_identity_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def poll(
    hub, ctx, worker_group: str, hostname: str = None, instance_identity: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Task runners call PollForTask to receive a task to perform from AWS Data Pipeline. The task runner specifies which tasks it can perform by setting a value for the workerGroup parameter. The task returned can come from any of the pipelines that match the workerGroup value passed in by the task runner and that was launched using the IAM user credentials specified by the task runner. If tasks are ready in the work queue, PollForTask returns a response immediately. If no tasks are available in the queue, PollForTask uses long-polling and holds on to a poll connection for up to a 90 seconds, during which time the first newly scheduled task is handed to the task runner. To accomodate this, set the socket timeout in your task runner to 90 seconds. The task runner should not call PollForTask again on the same workerGroup until it receives a response, and this can take up to 90 seconds.

    Args:
        worker_group(str): The type of task the task runner is configured to accept and process. The worker group is set as a field on objects in the pipeline when they are created. You can only specify a single value for workerGroup in the call to PollForTask. There are no wildcard values permitted in workerGroup; the string must be an exact, case-sensitive, match.
        hostname(str, optional): The public DNS name of the calling task runner. Defaults to None.
        instance_identity(Dict, optional): Identity information for the EC2 instance that is hosting the task runner. You can get this value from the instance using http://169.254.169.254/latest/meta-data/instance-id. For more information, see Instance Metadata in the Amazon Elastic Compute Cloud User Guide. Passing in this value proves that your task runner is running on an EC2 instance, and ensures the proper AWS Data Pipeline service charges are applied to your pipeline. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.for_task.poll(ctx, worker_group=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.for_task.poll worker_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="poll_for_task",
        op_kwargs={
            "workerGroup": worker_group,
            "hostname": hostname,
            "instanceIdentity": instance_identity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    reserved_db_instances_offering_id: str = None,
    db_instance_class: str = None,
    duration: str = None,
    product_description: str = None,
    offering_type: str = None,
    multi_az: bool = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists available reserved DB instance offerings.

    Args:
        reserved_db_instances_offering_id(str, optional): The offering identifier filter value. Specify this parameter to show only the available offering that matches the specified reservation identifier. Example: 438012d3-4052-4cc7-b2e3-8d3372e0e706 . Defaults to None.
        db_instance_class(str, optional): The DB instance class filter value. Specify this parameter to show only the available offerings matching the specified DB instance class. Defaults to None.
        duration(str, optional): Duration filter value, specified in years or seconds. Specify this parameter to show only reservations for this duration. Valid Values: 1 | 3 | 31536000 | 94608000 . Defaults to None.
        product_description(str, optional): Product description filter value. Specify this parameter to show only the available offerings that contain the specified product description.  The results show offerings that partially match the filter value. . Defaults to None.
        offering_type(str, optional): The offering type filter value. Specify this parameter to show only the available offerings matching the specified offering type. Valid Values: "Partial Upfront" | "All Upfront" | "No Upfront"  . Defaults to None.
        multi_az(bool, optional): A value that indicates whether to show only those reservations that support Multi-AZ. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.reserved_db_instance.offering.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.reserved_db_instance.offering.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_reserved_db_instances_offerings",
        op_kwargs={
            "ReservedDBInstancesOfferingId": reserved_db_instances_offering_id,
            "DBInstanceClass": db_instance_class,
            "Duration": duration,
            "ProductDescription": product_description,
            "OfferingType": offering_type,
            "MultiAZ": multi_az,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def purchase(
    hub,
    ctx,
    reserved_db_instances_offering_id: str,
    reserved_db_instance_id: str = None,
    db_instance_count: int = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Purchases a reserved DB instance offering.

    Args:
        reserved_db_instances_offering_id(str): The ID of the Reserved DB instance offering to purchase. Example: 438012d3-4052-4cc7-b2e3-8d3372e0e706.
        reserved_db_instance_id(str, optional): Customer-specified identifier to track this reservation. Example: myreservationID. Defaults to None.
        db_instance_count(int, optional): The number of instances to reserve. Default: 1 . Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.reserved_db_instance.offering.purchase(
                ctx, reserved_db_instances_offering_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.reserved_db_instance.offering.purchase reserved_db_instances_offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="purchase_reserved_db_instances_offering",
        op_kwargs={
            "ReservedDBInstancesOfferingId": reserved_db_instances_offering_id,
            "ReservedDBInstanceId": reserved_db_instance_id,
            "DBInstanceCount": db_instance_count,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    instance_names: List,
    availability_zone: str,
    bundle_id: str,
    attached_disk_mapping: Dict = None,
    instance_snapshot_name: str = None,
    user_data: str = None,
    key_pair_name: str = None,
    tags: List = None,
    add_ons: List = None,
    ip_address_type: str = None,
    source_instance_name: str = None,
    restore_date: str = None,
    use_latest_restorable_auto_snapshot: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more new instances from a manual or automatic snapshot of an instance. The create instances from snapshot operation supports tag-based access control via request tags and resource tags applied to the resource identified by instance snapshot name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_names(List): The names for your new instances.
        attached_disk_mapping(Dict, optional): An object containing information about one or more disk mappings. Defaults to None.
        availability_zone(str): The Availability Zone where you want to create your instances. Use the following formatting: us-east-2a (case sensitive). You can get a list of Availability Zones by using the get regions operation. Be sure to add the include Availability Zones parameter to your request.
        instance_snapshot_name(str, optional): The name of the instance snapshot on which you are basing your new instances. Use the get instance snapshots operation to return information about your existing snapshots. Constraint:   This parameter cannot be defined together with the source instance name parameter. The instance snapshot name and source instance name parameters are mutually exclusive.  . Defaults to None.
        bundle_id(str): The bundle of specification information for your virtual private server (or instance), including the pricing plan (e.g., micro_1_0).
        user_data(str, optional): You can create a launch script that configures a server with additional user data. For example, apt-get -y update.  Depending on the machine image you choose, the command to get software on your instance varies. Amazon Linux and CentOS use yum, Debian and Ubuntu use apt-get, and FreeBSD uses pkg. For a complete list, see the Amazon Lightsail Developer Guide. . Defaults to None.
        key_pair_name(str, optional): The name for your key pair. Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.
        add_ons(List, optional): An array of objects representing the add-ons to enable for the new instance. Defaults to None.
        ip_address_type(str, optional): The IP address type for the instance. The possible values are ipv4 for IPv4 only, and dualstack for IPv4 and IPv6. The default value is dualstack. Defaults to None.
        source_instance_name(str, optional): The name of the source instance from which the source automatic snapshot was created. Constraints:   This parameter cannot be defined together with the instance snapshot name parameter. The source instance name and instance snapshot name parameters are mutually exclusive.   Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the Amazon Lightsail Developer Guide.  . Defaults to None.
        restore_date(str, optional): The date of the automatic snapshot to use for the new instance. Use the get auto snapshots operation to identify the dates of the available automatic snapshots. Constraints:   Must be specified in YYYY-MM-DD format.   This parameter cannot be defined together with the use latest restorable auto snapshot parameter. The restore date and use latest restorable auto snapshot parameters are mutually exclusive.   Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the Amazon Lightsail Developer Guide.  . Defaults to None.
        use_latest_restorable_auto_snapshot(bool, optional): A Boolean value to indicate whether to use the latest available automatic snapshot. Constraints:   This parameter cannot be defined together with the restore date parameter. The use latest restorable auto snapshot and restore date parameters are mutually exclusive.   Define this parameter only when creating a new instance from an automatic snapshot. For more information, see the Amazon Lightsail Developer Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.from_.snapshot.create(
                ctx, instance_names=value, availability_zone=value, bundle_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.from_.snapshot.create instance_names=value, availability_zone=value, bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_instances_from_snapshot",
        op_kwargs={
            "instanceNames": instance_names,
            "attachedDiskMapping": attached_disk_mapping,
            "availabilityZone": availability_zone,
            "instanceSnapshotName": instance_snapshot_name,
            "bundleId": bundle_id,
            "userData": user_data,
            "keyPairName": key_pair_name,
            "tags": tags,
            "addOns": add_ons,
            "ipAddressType": ip_address_type,
            "sourceInstanceName": source_instance_name,
            "restoreDate": restore_date,
            "useLatestRestorableAutoSnapshot": use_latest_restorable_auto_snapshot,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of key-value pairs assigned to a target recovery point, backup plan, or backup vault.   ListTags are currently only supported with Amazon EFS backups.

    Args:
        resource_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the type of resource. Valid targets for ListTags are recovery points, backup plans, and backup vaults.
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.tags.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.tags.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_tags",
        op_kwargs={
            "ResourceArn": resource_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def revoke(
    hub, ctx, token: str, client_id: str, client_secret: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Revokes all of the access tokens generated by the specified refresh token. After the token is revoked, you can not use the revoked token to access Cognito authenticated APIs.

    Args:
        token(str): The token that you want to revoke.
        client_id(str): The client ID for the token that you want to revoke.
        client_secret(str, optional): The secret for the client ID. This is required only if the client ID has a secret. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.token.revoke(ctx, token=value, client_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.token.revoke token=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="revoke_token",
        op_kwargs={
            "Token": token,
            "ClientId": client_id,
            "ClientSecret": client_secret,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, config_id: str, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the Amazon S3 Storage Lens configuration tags. For more information about S3 Storage Lens, see Assessing your storage activity and usage with Amazon S3 Storage Lens  in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:DeleteStorageLensConfigurationTagging action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        config_id(str): The ID of the S3 Storage Lens configuration.
        account_id(str): The account ID of the requester.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.tagging.delete(
                ctx, config_id=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.tagging.delete config_id=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_storage_lens_configuration_tagging",
        op_kwargs={"ConfigId": config_id, "AccountId": account_id},
    )


async def get(hub, ctx, config_id: str, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the tags of Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Assessing your storage activity and usage with Amazon S3 Storage Lens  in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:GetStorageLensConfigurationTagging action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        config_id(str): The ID of the Amazon S3 Storage Lens configuration.
        account_id(str): The account ID of the requester.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.tagging.get(
                ctx, config_id=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.tagging.get config_id=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_storage_lens_configuration_tagging",
        op_kwargs={"ConfigId": config_id, "AccountId": account_id},
    )


async def put(hub, ctx, config_id: str, account_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Put or replace tags on an existing Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Assessing your storage activity and usage with Amazon S3 Storage Lens  in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:PutStorageLensConfigurationTagging action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        config_id(str): The ID of the S3 Storage Lens configuration.
        account_id(str): The account ID of the requester.
        tags(List): The tag set of the S3 Storage Lens configuration.  You can set up to a maximum of 50 tags. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.tagging.put(
                ctx, config_id=value, account_id=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.tagging.put config_id=value, account_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_storage_lens_configuration_tagging",
        op_kwargs={"ConfigId": config_id, "AccountId": account_id, "Tags": tags},
    )
